@@ -22,7 +22,7 @@ public:
     void setVolume(qint64 volume) override;
     void setMuted(bool muted) override;
     void setChannelVolume(int channel, qint64 volume) override;
-    void setChannelVolumes(const QVector<qint64> &channelVolumes) override;
+    void setChannelVolumes(const QList<qint64> &channelVolumes) override;
     void setDeviceIndex(quint32 deviceIndex) override;
 };
 
